@@ -198,6 +198,20 @@ class UnknownEndpointError(BaseEndpointResolverError, ValueError):
         '{service_name} in region {region_name}')
 
 
+class UnknownFIPSEndpointError(BaseEndpointResolverError):
+    """
+    Could not construct a FIPS endpoint.
+
+    :ivar service_name: The name of the service.
+    :ivar region_name: The name of the region.
+    """
+    fmt = (
+        'The provided FIPS pseudo-region "{region_name}" is not known for '
+        'the service "{service_name}". A FIPS compliant endpoint cannot be '
+        'constructed.'
+    )
+
+
 class ProfileNotFound(BotoCoreError):
     """
     The specified configuration profile was not found in the
@@ -500,12 +514,20 @@ class UnsupportedOutpostResourceError(BotoCoreError):
     )
 
 
+class UnsupportedS3ConfigurationError(BotoCoreError):
+    """Error when an unsupported configuration is used with access-points"""
+    fmt = (
+        'Unsupported configuration when using S3: {msg}'
+    )
+
+
 class UnsupportedS3AccesspointConfigurationError(BotoCoreError):
     """Error when an unsupported configuration is used with access-points"""
     fmt = (
         'Unsupported configuration when using S3 access-points: {msg}'
     )
 
+
 class InvalidEndpointDiscoveryConfigurationError(BotoCoreError):
     """Error when invalid value supplied for endpoint_discovery_enabled"""
     fmt = (
@@ -513,6 +535,7 @@ class InvalidEndpointDiscoveryConfigurationError(BotoCoreError):
         'Expected one of ("true", "false", "auto") but got {config_value}.'
     )
 
+
 class UnsupportedS3ControlConfigurationError(BotoCoreError):
     """Error when an unsupported configuration is used with S3 Control"""
     fmt = (
@@ -633,3 +656,9 @@ class CapacityNotAvailableError(BotoCoreError):
     fmt = (
         'Insufficient request capacity available.'
     )
+
+
+class InvalidProxiesConfigError(BotoCoreError):
+    fmt = (
+        'Invalid configuration value(s) provided for proxies_config.'
+    )
